import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { SvgNmrRealImag, SvgNmrOverlay3, SvgNmrOverlay3Aligned, SvgNmrAlignBottom, SvgNmrAlignCenter, } from 'cheminfo-font';
import { memo } from 'react';
import { FaDownload, FaFileDownload, FaFileImage, FaCopy, FaFileExport, FaFile, FaFileImport, } from 'react-icons/fa';
import { Toolbar, useOnOff } from 'react-science/ui';
import { useChartData } from '../context/ChartContext';
import { useLoader } from '../context/LoaderContext';
import { DropdownMenu } from '../elements/DropdownMenu';
import useCheckExperimentalFeature from '../hooks/useCheckExperimentalFeature';
import { useCheckToolsVisibility } from '../hooks/useCheckToolsVisibility';
import useDatumWithSpectraStatistics from '../hooks/useDatumWithSpectraStatistics';
import useExport from '../hooks/useExport';
import useToolsFunctions from '../hooks/useToolsFunctions';
import { useVerticalAlign } from '../hooks/useVerticalAlign';
import ImportPublicationStringModal from '../modal/ImportPublicationStringModal';
import { LoadJCAMPModal } from '../modal/LoadJCAMPModal';
import { useMetaInformationImportationModal } from '../modal/metaImportation';
import { options } from './ToolTypes';
const IMPORT_MENU = [
    {
        icon: _jsx(FaFile, {}),
        text: 'Import from file system (Press Ctrl + O)',
        data: {
            id: 'importFile',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Add JCAMP-DX from URL',
        data: {
            id: 'importJDX',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Generate spectrum from publication string',
        data: {
            id: 'importPublicationString',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Import meta information',
        data: {
            id: 'importMetaInformation',
        },
    },
];
const EXPORT_MENU = [
    {
        icon: _jsx(FaDownload, {}),
        text: 'Export as SVG',
        data: {
            id: 'svg',
        },
    },
    {
        icon: _jsx(FaFileImage, {}),
        text: 'Export as PNG',
        data: {
            id: 'png',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save data ( Press Ctrl + S )',
        data: {
            id: 'json',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save data as  ( Press Ctrl + Shift + S )',
        data: {
            id: 'advance_save',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save NMRE data',
        data: {
            id: 'nmre',
        },
    },
    {
        icon: _jsx(FaCopy, {}),
        text: 'Copy image to Clipboard ( Press Ctrl + C )',
        data: {
            id: 'copy',
        },
    },
];
function BasicToolBarInner({ verticalAlign, ftCounter, fidCounter, }) {
    const openLoader = useLoader();
    const openMetaInformationModal = useMetaInformationImportationModal();
    const isExperimentalFeature = useCheckExperimentalFeature();
    const isButtonVisible = useCheckToolsVisibility();
    const [isLoadJCAMPModalOpened, openLoadJCAMPModal, closeLoadJCAMPModal] = useOnOff(false);
    const [isPublicationStringModalOpened, openPublicationStringModal, closePublicationStringModal,] = useOnOff(false);
    const importMenu = isExperimentalFeature
        ? IMPORT_MENU
        : IMPORT_MENU.filter((item) => item.id !== 'importPublicationString');
    const exportMenu = isExperimentalFeature
        ? EXPORT_MENU
        : EXPORT_MENU.filter((item) => item.id !== 'nmre');
    const { isRealSpectrumShown, changeSpectrumViewHandler, changeDisplayViewModeHandler, alignSpectrumsVerticallyHandler, } = useToolsFunctions();
    const { saveAsSVGHandler, saveAsPNGHandler, saveAsJSONHandler, saveToClipboardHandler, saveAsHandler, } = useExport();
    function importHandler(data) {
        switch (data?.id) {
            case 'importFile':
                openLoader();
                break;
            case 'importJDX':
                openLoadJCAMPModal();
                break;
            case 'importPublicationString':
                openPublicationStringModal();
                break;
            case 'importMetaInformation':
                openMetaInformationModal();
                break;
            default:
        }
    }
    function exportHandler(data) {
        switch (data?.id) {
            case 'svg':
                void saveAsSVGHandler();
                break;
            case 'png':
                void saveAsPNGHandler();
                break;
            case 'json':
                saveAsJSONHandler();
                break;
            case 'advance_save':
                void saveAsHandler();
                break;
            case 'copy':
                void saveToClipboardHandler();
                break;
            default:
                break;
        }
    }
    return (_jsxs(_Fragment, { children: [_jsx(LoadJCAMPModal, { isOpen: isLoadJCAMPModalOpened, onCloseDialog: closeLoadJCAMPModal }), _jsx(ImportPublicationStringModal, { isOpen: isPublicationStringModalOpened, onClose: closePublicationStringModal }), isButtonVisible('import') && (_jsx(DropdownMenu, { placement: "right-start", onSelect: (data) => {
                    importHandler(data);
                }, targetTagName: "div", targetProps: { style: { flex: 'none' } }, options: importMenu, children: _jsx(Toolbar.Item, { id: options.import.id, title: options.import.label, icon: _jsx(FaFileImport, {}) }) })), isButtonVisible('exportAs') && (_jsx(DropdownMenu, { onSelect: (data) => {
                    exportHandler(data);
                }, placement: "right-start", targetTagName: "div", targetProps: { style: { flex: 'none' } }, options: exportMenu, children: _jsx(Toolbar.Item, { id: options.exportAs.id, title: options.exportAs.label, icon: _jsx(FaFileExport, {}) }) })), isButtonVisible('spectraStackAlignments') && ftCounter > 1 && (_jsx(Toolbar.Item, { id: "spectra-alignment", className: "cheminfo", title: "Spectra alignment ( Press s )", onClick: changeDisplayViewModeHandler, icon: verticalAlign === 'stack' ? (_jsx(SvgNmrOverlay3Aligned, {})) : (_jsx(SvgNmrOverlay3, {})) })), isButtonVisible('realImaginary') && (_jsx(Toolbar.Item, { id: "display", title: isRealSpectrumShown ? 'Display real ' : 'Display imaginary', onClick: changeSpectrumViewHandler, className: "cheminfo", icon: _jsx(SvgNmrRealImag, {}) })), isButtonVisible('spectraCenterAlignments') &&
                (ftCounter > 0 || fidCounter > 0) && (_jsx(Toolbar.Item, { id: "baseline-position", title: verticalAlign === 'bottom'
                    ? 'Baseline  center ( Press c )'
                    : 'Baseline  bottom ( Press c )', onClick: alignSpectrumsVerticallyHandler, className: "cheminfo", icon: _jsx(_Fragment, { children: verticalAlign === 'bottom' ? (_jsx(SvgNmrAlignCenter, {})) : (_jsx(SvgNmrAlignBottom, {})) }) }))] }));
}
const MemoizedBasicToolBar = memo(BasicToolBarInner);
export default function BasicToolBar() {
    const { displayerMode, view: { spectra: { activeTab }, }, } = useChartData();
    const verticalAlign = useVerticalAlign();
    const { fidCounter, ftCounter } = useDatumWithSpectraStatistics();
    return (_jsx(MemoizedBasicToolBar, { fidCounter,
        ftCounter,
        verticalAlign,
        displayerMode,
        activeTab }));
}
