import { jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
import { SvgNmrApodization, SvgNmrBaselineCorrection, SvgNmrFourierTransform, SvgNmrIntegrate, SvgNmrMultipleAnalysis, SvgNmrPeakPicking, SvgNmrPhaseCorrection, SvgNmrRangePicking, SvgNmrZeroFilling, } from 'cheminfo-font';
import { useState, useEffect, useCallback, memo } from 'react';
import { FaSearchPlus, FaExpand, FaDiceFour } from 'react-icons/fa';
import { PiKnifeBold } from 'react-icons/pi';
import { Toolbar } from 'react-science/ui';
import { useChartData } from '../context/ChartContext';
import { useDispatch } from '../context/DispatchContext';
import { useCheckToolsVisibility, } from '../hooks/useCheckToolsVisibility';
import useDatumWithSpectraStatistics from '../hooks/useDatumWithSpectraStatistics';
import useToolsFunctions from '../hooks/useToolsFunctions';
import { options } from './ToolTypes';
function FunctionToolBarInner({ defaultValue, ftCounter, }) {
    const [option, setOption] = useState('');
    const isButtonVisible = useCheckToolsVisibility();
    const dispatch = useDispatch();
    const { handleChangeOption, handleFullZoomOut } = useToolsFunctions();
    const handleChange = useCallback((selectedOption) => {
        setOption(selectedOption);
        handleChangeOption(selectedOption);
    }, [handleChangeOption]);
    useEffect(() => {
        setOption(defaultValue);
    }, [defaultValue]);
    const handleOnFFTFilter = useCallback(() => {
        dispatch({
            type: 'APPLY_FFT_FILTER',
        });
    }, [dispatch]);
    const handleFFtDimension1Filter = useCallback(() => {
        dispatch({
            type: 'APPLY_FFT_DIMENSION_1_FILTER',
        });
    }, [dispatch]);
    const handleFFtDimension2Filter = useCallback(() => {
        dispatch({
            type: 'APPLY_FFT_DIMENSION_2_FILTER',
        });
    }, [dispatch]);
    const toolItems = [
        {
            id: 'zoom',
            label: options.zoom.label,
            icon: _jsx(FaSearchPlus, {}),
        },
        {
            id: 'zoomOut',
            label: 'Horizontal zoom out ( Press f ), Horizontal and Vertical zoom out, double click ( Press ff )',
            onClick: handleFullZoomOut,
            icon: _jsx(FaExpand, {}),
        },
        {
            id: 'peakPicking',
            label: `${options.peakPicking.label} ( Press p )`,
            icon: _jsx(SvgNmrPeakPicking, {}),
        },
        {
            id: 'integral',
            label: `${options.integral.label} ( Press i )`,
            icon: _jsx(SvgNmrIntegrate, {}),
        },
        {
            id: 'zonePicking',
            label: `${options.zonePicking.label} ( Press r )`,
            icon: _jsx(FaDiceFour, {}),
        },
        {
            id: 'slicing',
            label: options.slicing.label,
            icon: _jsx(PiKnifeBold, {}),
        },
        {
            id: 'rangePicking',
            label: `${options.rangePicking.label} ( Press r )`,
            icon: _jsx(SvgNmrRangePicking, {}),
        },
        {
            id: 'multipleSpectraAnalysis',
            label: options.multipleSpectraAnalysis.label,
            icon: _jsx(SvgNmrMultipleAnalysis, {}),
            checkOptions: { checkSpectrumType: false },
            condition: ftCounter > 1,
        },
        {
            id: 'apodization',
            label: `${options.apodization.label} (Press a)`,
            icon: _jsx(SvgNmrApodization, {}),
        },
        {
            id: 'zeroFilling',
            label: `${options.zeroFilling.label} ( Press z )`,
            icon: _jsx(SvgNmrZeroFilling, {}),
        },
        {
            id: 'phaseCorrection',
            label: `${options.phaseCorrection.label} ( Press a )`,
            icon: _jsx(SvgNmrPhaseCorrection, {}),
        },
        {
            id: 'phaseCorrectionTwoDimensions',
            label: `${options.phaseCorrectionTwoDimensions.label} ( Press a )`,
            icon: _jsx(SvgNmrPhaseCorrection, {}),
        },
        {
            id: 'baselineCorrection',
            label: `${options.baselineCorrection.label} ( Press b )`,
            icon: _jsx(SvgNmrBaselineCorrection, {}),
        },
        {
            id: 'exclusionZones',
            label: `${options.exclusionZones.label} ( Press e )`,
            icon: _jsx(SvgNmrMultipleAnalysis, {}),
            checkOptions: { checkSpectrumType: false },
            condition: ftCounter > 0,
        },
        {
            id: 'fft',
            label: `${options.fft.label} ( Press t )`,
            onClick: handleOnFFTFilter,
            icon: _jsx(SvgNmrFourierTransform, {}),
        },
        {
            id: 'fftDimension1',
            label: options.fftDimension1.label,
            onClick: handleFFtDimension1Filter,
            icon: _jsx(SvgNmrFourierTransform, {}),
        },
        {
            id: 'fftDimension2',
            label: options.fftDimension2.label,
            onClick: handleFFtDimension2Filter,
            icon: _jsx(SvgNmrFourierTransform, {}),
        },
    ];
    return (_jsx(_Fragment, { children: toolItems.map((item) => {
            const { id, icon, label, checkOptions, onClick, condition } = item;
            return (isButtonVisible(id, checkOptions) &&
                (condition === undefined || condition) && (_jsx(Toolbar.Item, { onClick: onClick || (() => handleChange(id)), title: label, id: id, active: option === id, icon: icon }, id)));
        }) }));
}
const MemoizedFunctionToolBar = memo(FunctionToolBarInner);
export default function FunctionToolBar({ defaultValue = options.zoom.id, }) {
    const { displayerMode } = useChartData();
    const data = useDatumWithSpectraStatistics();
    return (_jsx(MemoizedFunctionToolBar, { ...data,
        displayerMode,
        defaultValue }));
}
